c=====================================================================
c
c     ------------------------------------------------------------
c     Fragmentation functions for: Pions
c            (includes mass-threshholds for c and b quarks)
c
c     Reference: A.Takacs, G.G.Barnafoldi TODO Ref.
c     ------------------------------------------------------------
c
c     ih, iset, x, qs are input; dh is output.
c     ih   = 0 : (pi^+ + pi^-)  /2
c     ih   = 1 : pi^+
c     ih   = 2 : pi^-
c
c     iset = 0 : LO         
c
c     x    = longitudinal-momentum fraction
c     qs   = fragmentation scale (in GeV)
c
c     dh   = parton label:
c     0    1    2    3    4    5    6    7    8     9    10
c     g    u   ubar  d   dbar  s   sbar  c   cbar   b   bbar
c
c     Lambda_QCD (in GeV):
c     0.088 in LO
c
c=====================================================================
      subroutine tss(ih,iset,x,qs,dh)
      implicit real*8 (a-h,o-z)
      dimension dh(0:10)
      dimension a(9),b(3)

c --- Mass-thresholds:
      rmcc= 1.43d0
      rmbb= 4.3d0
c --- Q0 (in GeV):      
      q0=1.0d0
c --- Qmin (in GeV):
      qmin= 1.0d0
c --- Qmax (in GeV):
      qmax= 1.0d5
c --- BAK
      if(qs.lt.qmin) qs=qmin 
      if(qmax.lt.qmax) qs=qmax
      
c --- LO FFs
      if (iset.eq.0) then
         rlam= 0.088d0
         s=  dlog(dlog(qs**2/rlam**2)/dlog(q0**2/rlam**2))
         sc= dlog(dlog(qs**2/rlam**2)/dlog(rmcc**2/rlam**2))
         sb= dlog(dlog(qs**2/rlam**2)/dlog(rmbb**2/rlam**2))

c ---------------------- LO PION ------------------------------
         b(1)=                            -105.30672486
         b(2)=                             1.09443479
         b(3)=                            -8.10728068
         a(1)=                             559.12437113
         a(2)=                            -37.19298855
         a(3)=                             -69.84502996
         a(4)=                             0.43794057
         a(5)=                            -0.28237834
         a(6)=                             0.05870202
         a(7)=                             124.76261033
         a(8)=                            -19.65696228
         a(9)=                             -6.47250816
         dpg= (b(1)+a(1)*s+a(2)*s**2+a(3)*s**3)*(1d0-x)*
     .        (1d0-((b(2)+a(4)*s+a(5)*s**2+a(6)*s**3)-
     .        1d0)*
     .        (b(3)+a(7)*s+a(8)*s**2+a(9)*s**3)*
     .        dlog(1d0-x))**
     .        (-1d0/((b(2)+a(4)*s+a(5)*s**2+a(6)*s**3)-
     .        1d0))
         b(1)=                           195.77797007
         b(2)=                             1.44979250
         b(3)=                            62.73493415
         a(1)=                           344.86017157
         a(2)=                          -116.23290223 
         a(3)=                            6.42483012
         a(4)=                            -6.63307040d-2
         a(5)=                             1.08796044d-2 
         a(6)=                            -1.38952490d-3
         a(7)=                           58.31199494
         a(8)=                           -19.05643153
         a(9)=                             2.5365429
         dpu= (b(1)+a(1)*s+a(2)*s**2+a(3)*s**3)*(1d0-x)*
     .        (1d0-((b(2)+a(4)*s+a(5)*s**2+a(6)*s**3)-
     .        1d0)*
     .        (b(3)+a(7)*s+a(8)*s**2+a(9)*s**3)*
     .        dlog(1d0-x))**
     .        (-1d0/((b(2)+a(4)*s+a(5)*s**2+a(6)*s**3)-
     .        1d0))  
         b(1)=                            13.78214162
         b(2)=                             1.12998843
         b(3)=                             4.54800364
         a(1)=                            17.27273051
         a(2)=                             6.81107137
         a(3)=                            -2.31271618
         a(4)=                             0.33682427
         a(5)=                            -0.21217642
         a(6)=                             0.04376087
         a(7)=                            11.6537218
         a(8)=                             2.6496825 
         a(9)=                            -0.75047386
         dpd= (b(1)+a(1)*s+a(2)*s**2+a(3)*s**3)*(1d0-x)*
     .        (1d0-((b(2)+a(4)*s+a(5)*s**2+a(6)*s**3)-
     .        1d0)*
     .        (b(3)+a(7)*s+a(8)*s**2+a(9)*s**3)*
     .        dlog(1d0-x))**
     .        (-1d0/((b(2)+a(4)*s+a(5)*s**2+a(6)*s**3)-
     .        1d0))                 
         b(1)=                          -86.83246548
         b(2)=                            2.21776886
         b(3)=                          -49.61147579
         a(1)=                          540.46363861
         a(2)=                         -403.57891001 
         a(3)=                           94.27383309
         a(4)=                           -0.67208589
         a(5)=                            0.27684145
         a(6)=                           -0.05185468
         a(7)=                          659.74308999
         a(8)=                         -634.05836276
         a(9)=                          179.37400454
         dpc=(b(1)+a(1)*sc+a(2)*sc**2+a(3)*sc**3)*(1d0-x)*
     .       (1d0-((b(2)+a(4)*sc+a(5)*sc**2+a(6)*sc**3)-
     .       1d0)*
     .       (b(3)+a(7)*sc+a(8)*sc**2+a(9)*sc**3)*
     .       dlog(1d0-x))**
     .       (-1d0/((b(2)+a(4)*sc+a(5)*sc**2+a(6)*sc**3)-1d0))
         b(1)=                          151.55016462
         b(2)=                            1.21071641
         b(3)=                           21.44374994
         a(1)=                           65.62343329
         a(2)=                          -10.78444222
         a(3)=                           -1.38333075
         a(4)=                            0.04497865
         a(5)=                           -0.03181062
         a(6)=                            0.0076724 
         a(7)=                           14.17355416
         a(8)=                            0.20146558
         a(9)=                           -0.06156434
         dpb= (b(1)+a(1)*sb+a(2)*sb**2+a(3)*sb**3)*(1d0-x)*
     .        (1d0-((b(2)+a(4)*sb+a(5)*sb**2+a(6)*sb**3)-
     .        1d0)*
     .        (b(3) +a(7)*sb+a(8)*sb**2+a(9)*sb**3)*
     .        dlog(1d0-x))**
     .        (-1d0/((b(2)+a(4)*sb+a(5)*sb**2+a(6)*sb**3)-
     .        1d0))  
      
c --- NLO FFs
      else
         if(iset.ne.1)write(*,*)'iset must be = 0 (LO)'
      endif

c --- Evaluate different contributions
c      dpd =      dpu
      if (qs.lt.rmbb) then
         dpb  = 0d0
      endif
      if (qs.lt.rmcc) then
         dpc  = 0d0
      endif
      if (ih.eq.0) then
         dh(0)= dpg
         dh(1)= (dpu+dpd)/2.0d0
         dh(2)= (dpu+dpd)/2.0d0
         dh(3)= (dpu+dpd)/2.0d0
         dh(4)= (dpu+dpd)/2.0d0
         dh(5)= dpd
         dh(6)= dpd
         dh(7)= dpc
         dh(8)= dpc
         dh(9)= dpb
         dh(10)=dpb      
      else if (ih.eq.1) then
         dh(0)= dpg
         dh(1)= dpu
         dh(2)= dpd
         dh(3)= dpd
         dh(4)= dpu
         dh(5)= dpd
         dh(6)= dpd
         dh(7)= dpc
         dh(8)= dpc
         dh(9)= dpb
         dh(10)=dpb
      else if (ih.eq.2) then
         dh(0)= dpg
         dh(1)= dpd
         dh(2)= dpu
         dh(3)= dpu
         dh(4)= dpd
         dh(5)= dpd
         dh(6)= dpd
         dh(7)= dpc
         dh(8)= dpc
         dh(9)= dpb
         dh(10)=dpb
      end if
      return
      end
      
